@@ -438,13 +438,13 @@ renderer_param_value_edited_cb (GtkCellRendererText *renderer,
 
 			dtype = gda_query_field_value_get_dict_type (GDA_QUERY_FIELD_VALUE (field));
 			if (dtype)
-				vtype = gda_dict_type_get_gda_type (dtype);
+				vtype = gda_dict_type_get_g_type (dtype);
 			else
 				g_object_get (G_OBJECT (field), "gda-type", &vtype, NULL);
 
 			dh = gda_dict_get_default_handler (gda_object_get_dict (GDA_OBJECT (field)), vtype);
 			value = gda_data_handler_get_value_from_sql (dh, new_text, 
-								    gda_query_field_value_get_gda_type (GDA_QUERY_FIELD_VALUE (field)));
+								    gda_query_field_value_get_g_type (GDA_QUERY_FIELD_VALUE (field)));
 			if (value) {
 				gda_query_field_value_set_value (GDA_QUERY_FIELD_VALUE (field), value);
 				gda_value_free (value);
@@ -531,7 +531,7 @@ renderer_param_nullok_toggled_cb (GtkCellRendererToggle *renderer,
 
 			/* we need to force the "changed" signal emission because GdaQuery normally does
 			 * not do it in this case */
-			gda_object_changed (GDA_OBJECT (pedit->priv->query));
+			gda_object_signal_emit_changed (GDA_OBJECT (pedit->priv->query));
 		}
 		
 		list = g_slist_next (list);
@@ -557,7 +557,7 @@ renderer_param_isparam_toggled_cb (GtkCellRendererToggle *renderer,
 
 			/* we need to force the "changed" signal emission because GdaQuery normally does
 			 * not do it in this case */
-			gda_object_changed (GDA_OBJECT (pedit->priv->query));
+			gda_object_signal_emit_changed (GDA_OBJECT (pedit->priv->query));
 		}
 		
 		list = g_slist_next (list);
@@ -631,7 +631,7 @@ query_changed_cb (GdaQuery *query, QueryParamsEditor *pedit)
 		else
 			valstr = g_strdup ("");
 
-		typestr = gda_type_to_string (gda_parameter_get_gda_type (param));
+		typestr = gda_g_type_to_string (gda_parameter_get_g_type (param));
 		
 		/* modify the model at iter */
 		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
