@@ -61,8 +61,8 @@ enum _QueryParamsMode {
  * Generic widget's methods 
 */
 GType      query_params_editor_get_type            (void);
-GtkWidget *query_params_editor_new                 (GnomeDbQuery *query, guint mode);
-void       query_params_editor_set_query           (QueryParamsEditor *editor, GnomeDbQuery *query);
+GtkWidget *query_params_editor_new                 (GdaQuery *query, guint mode);
+void       query_params_editor_set_query           (QueryParamsEditor *editor, GdaQuery *query);
 
 G_END_DECLS
 
